:orphan:

Examples
--------

Below is a gallery of StateMachine examples.



.. raw:: html

    <div class="sphx-glr-thumbnails">


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="Demonstrates the concept of cycle states.">

.. only:: html

  .. image:: /auto_examples/images/thumb/sphx_glr_traffic_light_machine_thumb.svg
    :alt: Traffic light machine

  :ref:`sphx_glr_auto_examples_traffic_light_machine.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Traffic light machine</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="An StateMachine that demonstrates Guards being used to control the state flow.">

.. only:: html

  .. image:: /auto_examples/images/thumb/sphx_glr_order_control_machine_thumb.svg
    :alt: Order control machine

  :ref:`sphx_glr_auto_examples_order_control_machine.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Order control machine</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="An StateMachine that demonstrates Actions being used on a rich model.">

.. only:: html

  .. image:: /auto_examples/images/thumb/sphx_glr_order_control_rich_model_machine_thumb.svg
    :alt: Order control machine (rich model)

  :ref:`sphx_glr_auto_examples_order_control_rich_model_machine.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Order control machine (rich model)</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="An StateMachine for the well know game.">

.. only:: html

  .. image:: /auto_examples/images/thumb/sphx_glr_guess_the_number_machine_thumb.svg
    :alt: Guess the number machine

  :ref:`sphx_glr_auto_examples_guess_the_number_machine.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">Guess the number machine</div>
    </div>


.. raw:: html

    <div class="sphx-glr-thumbcontainer" tooltip="A StateMachine that exercices all possible Actions and Guards.">

.. only:: html

  .. image:: /auto_examples/images/thumb/sphx_glr_all_actions_machine_thumb.svg
    :alt: All actions machine

  :ref:`sphx_glr_auto_examples_all_actions_machine.py`

.. raw:: html

      <div class="sphx-glr-thumbnail-title">All actions machine</div>
    </div>


.. raw:: html

    </div>


.. toctree::
   :hidden:

   /auto_examples/traffic_light_machine
   /auto_examples/order_control_machine
   /auto_examples/order_control_rich_model_machine
   /auto_examples/guess_the_number_machine
   /auto_examples/all_actions_machine

